@@ -6,6 +6,7 @@ you can actually reach the app's views (provided it has any views, of course).
 """
 from django.conf.urls.defaults import include, patterns, url
 from django.contrib import admin
+from django.views.generic import TemplateView
 
 
 admin.autodiscover()
@@ -13,6 +14,7 @@ admin.autodiscover()
 
 urlpatterns = patterns(
     '',
-    url(r'', include('unshorten.urls')),
     url(r'^admin/', include(admin.site.urls)),
+    url(r'^notifications/', include('object_events.urls')),
+    url(r'^test/$', TemplateView.as_view(template_name='test_app/tag.html')),
 )
